# EzyDB-bson  
EzyDB-bson is a lightweight, file-based NoSQL database system designed for Python developers. Plugin for EzyDB.

> [!WARNING]  
> This tool is in **BETA** / **DEVELOPMENT** stage. Please use latest version.   
